@@ -2,9 +2,9 @@ from contextlib import closing
 from sqlite3 import Connection
 from threading import Lock
 
-import graphlite.sql as SQL
 from graphlite.query import Query
 from graphlite.transaction import Transaction
+import graphlite.sql as SQL
 
 
 class Graph(object):
@@ -48,25 +48,26 @@ class Graph(object):
 
     def __contains__(self, edge):
         """
-        Checks if an edge exists within the database with
-        the given source and destination nodes.
+        Checks if an edge exists within the database
+        with the given source and destination nodes.
 
         :param edge: The edge to query.
         """
         with closing(self.db.cursor()) as cursor:
             cursor.execute(*SQL.select_one(edge.src, edge.rel, edge.dst))
-            return bool(cursor.fetchone())
+            return bool(cursor.fetchall())
 
     @property
     def find(self):
         """
-        Returns a Query object.
+        Returns a Query object that acts on the graph.
         """
         return Query(self.db)
 
     def transaction(self):
         """
-        Returns a Transaction object. All atomic operations
-        must then be performed on the transaction object.
+        Returns a Transaction object. All modifying
+        operations, i.e. ``store``, ``delete`` must
+        then be performed on the transaction object.
         """
-        return Transaction(self.db, lock=self.lock)
+        return Transaction(self.db, self.lock)
