@@ -1,7 +1,6 @@
 CREATE_TABLE = '''\
 CREATE TABLE IF NOT EXISTS %s
 (
-    id INTEGER PRIMARY KEY AUTOINCREMENT,
     src UNSIGNED INTEGER,
     dst UNSIGNED INTEGER
 )
@@ -16,7 +15,7 @@ INDEXES = (
 difference = 'EXCEPT'
 intersection = 'INTERSECT'
 union = 'UNION'
-begin = 'BEGIN'
+begin = 'BEGIN TRANSACTION'
 
 
 def store(src, rel, dst):
@@ -29,7 +28,7 @@ def store(src, rel, dst):
     :param dst: The destination node.
     """
     smt = 'INSERT INTO %s (src, dst) VALUES (?, ?)'
-    return (smt % (rel)), (src, dst)
+    return smt % rel, (src, dst)
 
 
 def remove(src, rel, dst):
@@ -42,7 +41,7 @@ def remove(src, rel, dst):
     :param rel: The relation.
     :param dst: The destination node.
     """
-    smt = 'DELETE FROM %s' % (rel)
+    smt = 'DELETE FROM %s' % rel
     queries = []
     params = []
 
@@ -69,7 +68,7 @@ def forwards_relation(src, rel):
     :param rel: The relation.
     """
     statement = 'SELECT dst FROM %s WHERE src = ?'
-    return statement % (rel), (src,)
+    return statement % rel, (src,)
 
 
 def inverse_relation(dst, rel):
@@ -81,7 +80,7 @@ def inverse_relation(dst, rel):
     :param rel: The relation.
     """
     statement = 'SELECT src FROM %s WHERE dst = ?'
-    return statement % (rel), (dst,)
+    return statement % rel, (dst,)
 
 
 def select_one(src, rel, dst):
@@ -93,8 +92,8 @@ def select_one(src, rel, dst):
     :param rel: The relation.
     :param dst: The destination node.
     """
-    smt = 'SELECT id FROM %s WHERE src = ? AND dst = ? LIMIT 1'
-    return smt % (rel), (src, dst)
+    smt = 'SELECT src FROM %s WHERE src = ? AND dst = ? LIMIT 1'
+    return smt % rel, (src, dst)
 
 
 def compound_fwd_query(query, rel):
@@ -107,14 +106,14 @@ def compound_fwd_query(query, rel):
     :param rel: The relation.
     """
     smt = 'SELECT dst FROM %s WHERE src IN (%s)'
-    return smt % (rel, query), tuple()
+    return smt % (rel, query), ()
 
 
 def compound_inv_query(query, rel, dst):
     """
     Create a compound inverse query, similar to
-    :meth:``compound_fw_query`` but only selects
-    the source nodes given a destination node.
+    :meth:``compound_fw_query`` but only selects the
+    source nodes given a destination node.
 
     :param query: The SQL subquery.
     :param rel: The relation.
@@ -122,3 +121,19 @@ def compound_inv_query(query, rel, dst):
     """
     smt = 'SELECT src FROM %s WHERE src IN (%s) AND dst = ?'
     return smt % (rel, query), (dst,)
+
+
+def limit(lower, upper):
+    """
+    Returns a SQlite-compliant LIMIT statement that
+    takes the *start* and *stop* into account, also
+    taking into account the fact that these values are
+    lower and upper bounds.
+
+    :param lower: The lower bound.
+    :param upper: The upper bound.
+    """
+    offset = lower or 0
+    lim = (upper - offset) if upper else -1
+    smt = 'LIMIT %d OFFSET %d' % (lim, offset)
+    return smt, ()
