@@ -24,16 +24,6 @@ class Transaction(object):
         self.lock = lock
         self.ops = []
 
-    def store(self, edge):
-        """
-        Store an edge in the database. Both the source
-        and destination nodes must be specified, as
-        well as the relation.
-
-        :param edge: The edge.
-        """
-        self.store_many((edge,))
-
     def store_many(self, edges):
         """
         Store many edges into the database. Similar to the
@@ -44,6 +34,28 @@ class Transaction(object):
         """
         self.ops.append((SQL.store, edges))
 
+    def delete_many(self, edges):
+        """
+        Delete multiple edge queries from the database. Best
+        used when you have a fairly large generator that
+        shouldn't be loaded into memory at once for efficiency
+        reasons.
+
+        :param edges: An iterable of edges or ``Graph.find``
+            style edge queries to delete.
+        """
+        self.ops.append((SQL.remove, edges))
+
+    def store(self, edge):
+        """
+        Store an edge in the database. Both the source
+        and destination nodes must be specified, as
+        well as the relation.
+
+        :param edge: The edge.
+        """
+        self.store_many((edge,))
+
     def delete(self, edge):
         """
         Deletes an edge from the database. Either the
@@ -54,23 +66,13 @@ class Transaction(object):
         """
         self.delete_many((edge,))
 
-    def delete_many(self, edges):
-        """
-        Delete multiple edge queries from the database. Best
-        used when you have a fairly large generator that
-        shouldn't be loaded into memory at once for efficiency
-        reasons.
-
-        :param edges: An iterable of edge queries to delete.
-        """
-        self.ops.append((SQL.remove, edges))
-
     def abort(self):
         """
         Raises an ``AbortSignal``. If you used the
         ``Graph.transaction`` context manager this
         exception is automatically caught and ignored.
         """
+        self.clear()
         raise AbortSignal
 
     @property
@@ -100,16 +102,26 @@ class Transaction(object):
                             dst=edge.dst,
                         ))
 
+    def clear(self):
+        """
+        Clears all the operations registered on the
+        transaction object.
+        """
+        del self.ops[:]
+
     def commit(self):
         """
         Commits the stored changes to the database.
         Note that you `do not` have to call this
         function if you used the transaction object
-        as a context manager, or the transaction will
-        be committed twice.
+        as a context manager. Note that a transaction
+        can only be committed once.
         """
-        with self.lock:
-            self.perform_ops()
+        try:
+            with self.lock:
+                self.perform_ops()
+        finally:
+            self.clear()
 
     def __enter__(self):
         """
